pype32.directories.NETDirectory

Package pype32 :: Module directories :: Class NETDirectory |
[hide private]
[frames] | no frames]

# Class NETDirectory

source code

                     object --+
                              |
    baseclasses.BaseStructClass --+
                                  |
                                 NETDirectory

NETDirectory object.

Instance Methods | [hide private]
__init__(self, shouldPack=True) A class to abstract data from the .NET PE format. | source code
getType(self) Returns consts.NET_DIRECTORY. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Inherited from baseclasses.BaseStructClass
__len__(self) | source code
__str__(self) str(x) | source code
dict |
getFields(self) Returns all the class attributues. | source code
sizeof(self) | source code

Static Methods | [hide private]
NETDirectory |
parse(readDataInstance) Returns a new NETDirectory object. | source code

Instance Variables | [hide private]
| directory NetDirectory directory.
| netMetaDataHeader NetMetaDataHeader netMetaDataHeader.
| netMetaDataStreams NetMetaDataStreams netMetaDataStreams.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
A class to abstract data from the .NET PE format. Parameters: `shouldPack` (bool) - (Optional) If set to c{True}, the object will be packed. If set to `False`, the object won't be packed. Overrides: object.__init__

### parse(readDataInstance) Static Method | source code
Returns a new NETDirectory object. Parameters: `readDataInstance` (ReadData) - A ReadData object with data to be parsed as a NETDirectory object. Returns: NETDirectory A new NETDirectory object.

### getType(self) | source code
Returns consts.NET_DIRECTORY. Raises: `NotImplementedError` - The method wasn't implemented in the inherited class. Overrides: baseclasses.BaseStructClass.getType